@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
-our $DATE = '2015-09-08'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-10-08'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
 use strict;
@@ -592,6 +592,16 @@ sub delete_section {
         @line_ranges = () if !defined($line_ranges[0]);
     }
 
+    if ($opts->{cond}) {
+        @line_ranges = grep {
+            !$opts->{cond}->(
+                $self,
+                linum_start => $_->[0],
+                linum_end   => $_->[1],
+            );
+        } @line_ranges;
+    }
+
     my $num_deleted = 0;
     for my $line_range (reverse @line_ranges) {
         next unless defined $line_range;
@@ -628,6 +638,20 @@ sub delete_key {
         @linums = () if !defined($linums[0]);
     }
 
+    if ($opts->{cond}) {
+        @linums = grep {
+            my $line = $self->{_parsed}[$_-1];
+            !$opts->{cond}->(
+                $self,
+                linum     => $_,
+                parsed    => $line,
+                key       => $line->[COL_K_KEY],
+                raw_value => $line->[COL_K_VALUE_RAW],
+                # XXX value
+            );
+        } @linums;
+    }
+
     my $num_deleted = 0;
     for my $linum (reverse @linums) {
         splice @$p, $linum-1, 1;
@@ -716,7 +740,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.21 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-09-08.
+This document describes version 0.22 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-10-08.
 
 =head1 SYNOPSIS
 
@@ -815,6 +839,13 @@ Options:
 If set to 1, then will delete all occurrences. By default only delete the first
 occurrence.
 
+=item * cond => code
+
+Will only delete key if C<cond> returns true. C<cond> will be called with C<<
+($self, %args) >> where the hash will contain these keys: C<linum> (int, line
+number), C<parsed> (array, parsed line), C<key> (string, key name), C<value>
+(NOT YET IMPLEMENTED), C<raw_value> (str, raw/undecoded value).
+
 =back
 
 =head2 $doc->delete_section([\%opts, ]$section) => $num_deleted
@@ -830,6 +861,12 @@ Options:
 If set to 1, then will delete all occurrences. By default only delete the first
 occurrence.
 
+=item * cond => code
+
+Will only delete section if C<cond> returns true. C<cond> will be called with
+C<< ($self, %args) >> where the hash will contain these keys: C<linum_start>
+(int, starting line number), C<linum_end> (int, ending line number).
+
 =back
 
 =head2 $doc->dump([ \%opts ]) => hoh
